@@ -64,7 +64,7 @@ class Exceptions:
 
 class AppflowClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html)
     """
 
@@ -80,7 +80,7 @@ class AppflowClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#can_paginate)
         """
 
@@ -94,9 +94,10 @@ class AppflowClient(BaseClient):
         kmsArn: str = None
     ) -> CreateConnectorProfileResponseTypeDef:
         """
-        Creates a new connector profile associated with your AWS account.
+        Creates a new connector profile associated with your Amazon Web Services
+        account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client.create_connector_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client.create_connector_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#create_connector_profile)
         """
 
@@ -115,7 +116,7 @@ class AppflowClient(BaseClient):
         """
         Enables your application to create a new flow using Amazon AppFlow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client.create_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client.create_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#create_flow)
         """
 
@@ -125,7 +126,7 @@ class AppflowClient(BaseClient):
         """
         Enables you to delete an existing connector profile.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client.delete_connector_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client.delete_connector_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#delete_connector_profile)
         """
 
@@ -133,7 +134,7 @@ class AppflowClient(BaseClient):
         """
         Enables your application to delete an existing flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client.delete_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client.delete_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#delete_flow)
         """
 
@@ -148,7 +149,7 @@ class AppflowClient(BaseClient):
         Provides details regarding the entity used with the connector, with a
         description of the data model for each entity.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client.describe_connector_entity)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client.describe_connector_entity)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_connector_entity)
         """
 
@@ -164,7 +165,7 @@ class AppflowClient(BaseClient):
         Returns a list of `connector-profile` details matching the provided `connector-
         profile` names and `connector-types`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client.describe_connector_profiles)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client.describe_connector_profiles)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_connector_profiles)
         """
 
@@ -174,7 +175,7 @@ class AppflowClient(BaseClient):
         """
         Describes the connectors vended by Amazon AppFlow for specified connector types.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client.describe_connectors)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client.describe_connectors)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_connectors)
         """
 
@@ -182,7 +183,7 @@ class AppflowClient(BaseClient):
         """
         Provides a description of the specified flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client.describe_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client.describe_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_flow)
         """
 
@@ -192,7 +193,7 @@ class AppflowClient(BaseClient):
         """
         Fetches the execution history of the flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client.describe_flow_execution_records)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client.describe_flow_execution_records)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_flow_execution_records)
         """
 
@@ -206,7 +207,7 @@ class AppflowClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#generate_presigned_url)
         """
 
@@ -220,7 +221,7 @@ class AppflowClient(BaseClient):
         """
         Returns the list of available connector entities supported by Amazon AppFlow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client.list_connector_entities)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client.list_connector_entities)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#list_connector_entities)
         """
 
@@ -230,7 +231,7 @@ class AppflowClient(BaseClient):
         """
         Lists all of the flows associated with your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client.list_flows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client.list_flows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#list_flows)
         """
 
@@ -238,7 +239,7 @@ class AppflowClient(BaseClient):
         """
         Retrieves the tags that are associated with a specified flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#list_tags_for_resource)
         """
 
@@ -246,7 +247,7 @@ class AppflowClient(BaseClient):
         """
         Activates an existing flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client.start_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client.start_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#start_flow)
         """
 
@@ -254,7 +255,7 @@ class AppflowClient(BaseClient):
         """
         Deactivates the existing flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client.stop_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client.stop_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#stop_flow)
         """
 
@@ -262,7 +263,7 @@ class AppflowClient(BaseClient):
         """
         Applies a tag to the specified flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#tag_resource)
         """
 
@@ -270,7 +271,7 @@ class AppflowClient(BaseClient):
         """
         Removes a tag from the specified flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#untag_resource)
         """
 
@@ -284,7 +285,7 @@ class AppflowClient(BaseClient):
         """
         Updates a given connector profile associated with your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client.update_connector_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client.update_connector_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#update_connector_profile)
         """
 
@@ -293,14 +294,14 @@ class AppflowClient(BaseClient):
         *,
         flowName: str,
         triggerConfig: "TriggerConfigTypeDef",
+        sourceFlowConfig: "SourceFlowConfigTypeDef",
         destinationFlowConfigList: List["DestinationFlowConfigTypeDef"],
         tasks: List["TaskTypeDef"],
-        description: str = None,
-        sourceFlowConfig: "SourceFlowConfigTypeDef" = None
+        description: str = None
     ) -> UpdateFlowResponseTypeDef:
         """
         Updates an existing flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/appflow.html#Appflow.Client.update_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/appflow.html#Appflow.Client.update_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#update_flow)
         """
